@@ -1,4 +1,5 @@
 import json
+from pathlib import Path
 
 import requests
 from django.conf import settings
@@ -44,3 +45,24 @@ def exec_algo(algo_name, **params):
         raise ValueError
     return {}
 
+
+def upload_file(file_path):
+    url = "{}/api/algo/file_upload/".format(settings.SERVER_URL)
+    file_path_obj = Path(file_path)
+    file_type_dict = {
+        '.txt': 'text/plain',
+        '.csv': 'text/csv',
+        '.json': 'application/json',
+        '.pdf': 'application/pdf',
+        '.zip': 'application/zip',
+        '.png': 'image/png',
+        '.jpg': 'image/jpeg',
+        '.md': 'text/plain',
+    }
+    file_type = file_type_dict.get(file_path_obj.suffix, 'text/plain')
+    files = [
+        ('file', (file_path_obj.name, open(str(file_path_obj.absolute()), 'rb'), file_type))
+    ]
+    response = requests.request("POST", url, files=files)
+    res = response.json()
+    return res.get('file', '')
