@@ -87,8 +87,11 @@ def access_system(jwt_token):
         'Content-Type': 'application/json'
     }
     response = requests.request("POST", url, headers=headers, data=payload)
-    res_json = response.json()
-    is_valid = res_json.get('result', {}).get('access', False)
+    if response.status_code == 200:
+        res_json = response.json()
+        is_valid = res_json.get('result', {}).get('access', False)
+    else:
+        is_valid = False
     return is_valid
 
 
